@@ -29,13 +29,17 @@ def request(payload):
         "Interface-Version": f"Chase Paymentech Python SDK/{version}"
     }
 
+    # If we are forcing failover, skip the first URL
+    if paymentech.configuration.get("failover", False):
+        urls = urls[1:]
+
     for url in urls:
         for attempt in range(maximum_attempts):
             try:
                 response = requests.post(url, data=payload, headers=headers)
 
                 if response and response.text:
-                    return response.text
+                    return trace, response.text
             except Exception:
                 pass
 
